#!/usr/bin/perl

use strict;
use warnings;

# Script to split up the old guildcafe blog entries on this pattern:

# <div class="post" id="12345">
#   <h3><img blah blah blah> <small>[May 17, 2007]</small> Post Title</h3>
#      [HTML content]
#    [last line of content]</div>

# Note: embedded "div" tags in blog entries will break this script.

# Generates output file suitable for import into... something. Wordpress has a 
# size limit, so it generates one RSS file per entry. (hehe)

my ($out_file_name) = 'blog_rss.xml';    # edit to taste

  # Spit out RSS 2.0 entry
  if (not open( OUTFILE, '>', $out_file_name )) {
    die "Can not open $out_file_name";
  }

  # Note: assumes everything is ascii, because I don't feel like
  # using a proper XML writer. Sorry if this is a problem. :(

  print OUTFILE '<?xml version="1.0" encoding="utf-8"?>', "\n";
  print OUTFILE '<rss version="2.0">', "\n";

  # I don't know if RSS channel information is useful to a blog 
  # import program, but who knows, yours might choke if it's missing. :)
  print OUTFILE "<channel>\n";
  print OUTFILE "  <title>GuildCafe Blog Archive</title>\n";
  print OUTFILE "  <description>Recovered GuildCafe Blog</description>\n";
  # print OUTFILE "  <lastBuildDate>Wed, 3 Sep 2008 12:00:00 GMT</lastBuildDate>\n";
  print OUTFILE "  <language>en-us</language>\n";


# header:

my ($post_id, $title, $date, $allcontent);

FILE_LOOP: while (1) # Go Go Go!
{
  # Find start of section, get ID.
  ID_LOOP: while (<>)
  {
    if ( /\<div class=\'post\' id=\'(\d+)\'/)
    {
      $post_id = $1;
      if (not $post_id) {
        die "Could not extract the post ID number?";
      }

      last ID_LOOP;
    }
  }

  if (eof()) {
    last FILE_LOOP;
  }

  # Read title and date
  $_ = <>;
  if ( /\<h3\>\<[^>]*\>.*\<small\>\[(.+)\] *\<\/small\> *([^<]+)\<\/h3\>/ )
  {
    $date = $1;
    $title = $2;

    if (not $date) { die "Could not retrieve date"; }
    if (not $title) { die "Could not retrieve title"; }
  }

  # Read content to end-div.

  $allcontent = '';
  BODY_LOOP: while (<>)
  {
    if ( /(.*)\<\/div\>/ )
    {
      $allcontent .= $1;
      last BODY_LOOP;
    }
    else
    {
      $allcontent .= $_;
    }
  }


  print OUTFILE "<item>\n";
  print OUTFILE " <title>$title</title>\n";
  print OUTFILE " <link>http://example.com/item/$post_id</link>\n";
  print OUTFILE " <guid>http://example.com/item/$post_id</guid>\n";
  print OUTFILE " <pubDate>$date</pubDate>\n";

  # Note: compliant RSS parsers should include the CDATA wrapper, 
  # while wordpress just sticks it into the document. :/
  # print OUTFILE " <description><![CDATA[ $allcontent ]]</description>\n";
  print OUTFILE " <description> $allcontent </description>\n";

  print OUTFILE "</item>\n";

  if (eof())
  {
    last FILE_LOOP;
  }
}

  # Ye footer
  print OUTFILE "</channel>\n";
  print OUTFILE "</rss>\n";
  close( OUTFILE ) or die "error closing output file";

exit 0;                         # hooray!


